@@ -1,5 +1,10 @@
 var NAVTREEINDEX17 =
 {
+"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0":[8,6,4,7,0],
+"structpw__client__events.html":[8,3,3,2],
+"structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[8,3,3,2,0],
+"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[8,3,3,2,1],
+"structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[8,3,3,2,2],
 "structpw__client__info.html":[8,3,3,1],
 "structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[8,3,3,1,0],
 "structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[8,3,3,1,1],
@@ -244,10 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__impl__factory__events.html#a61bf0bc918867a1315f7c09e870cf297":[8,4,3,1,0],
 "structpw__impl__factory__events.html#a6bb4670f4a96e31d0f1f30d3fc763bc6":[8,4,3,1,3],
 "structpw__impl__factory__events.html#abb0d82e4263cbe36b38aa10eef130ad0":[8,4,3,1,1],
-"structpw__impl__factory__events.html#ae608dbd84c609b5b8a6d7c232e5a569f":[8,4,3,1,2],
-"structpw__impl__factory__implementation.html":[8,4,3,2],
-"structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[8,4,3,2,1],
-"structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[8,4,3,2,0],
-"structpw__impl__link.html":[8,4,4,2],
-"structpw__impl__link.html":[8,4,8,3]
+"structpw__impl__factory__events.html#ae608dbd84c609b5b8a6d7c232e5a569f":[8,4,3,1,2]
 };
