@@ -1,5 +1,11 @@
 var NAVTREEINDEX19 =
 {
+"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3":[8,4,13,2,0],
+"structpw__protocol__server.html#a0b93bd3cd5a2680d8ece4796826406fc":[8,4,13,2,1],
+"structpw__protocol__server.html#acc7b1e9530a048b084976fc647ab446f":[8,4,13,2,4],
+"structpw__protocol__server.html#ae953d4026c613d91a0cb34398d3f4367":[8,4,13,2,2],
+"structpw__proxy.html":[8,3,13,2],
+"structpw__proxy__events.html":[8,3,13,1],
 "structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[8,3,13,1,4],
 "structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158":[8,3,13,1,6],
 "structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2":[8,3,13,1,0],
@@ -243,11 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__dbus__connection__events.html#a481b39049a46ec7d8519c8d2c9318968":[8,7,9,1,2,2],
 "structspa__dbus__methods.html":[8,7,9,1,4],
 "structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28":[8,7,9,1,4,1],
-"structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[8,7,9,1,4,0],
-"structspa__debug__context.html":[8,7,3,10],
-"structspa__debug__context.html#af9f0b4808459f1701213a4dbac14601f":[8,7,3,10,0],
-"structspa__debug__file__ctx.html":[8,7,3,11],
-"structspa__debug__file__ctx.html#a34708c6380f0ca51b9d318a089306401":[8,7,3,11,1],
-"structspa__debug__file__ctx.html#a817d19045e3261030ec8e38842a018c3":[8,7,3,11,0],
-"structspa__debug__log__ctx.html":[8,7,3,12]
+"structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[8,7,9,1,4,0]
 };
